@@ -2,18 +2,9 @@ from PyObjCTools.TestSupport import *
 
 import DiskArbitration
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-try:
-    long
-
-except NameError:
-    long = int
 
 class TestDADisk (TestCase):
+    @min_os_level('10.10')
     def test_constants(self):
         self.assertIsInstance(DiskArbitration.kDADiskDescriptionVolumeKindKey, unicode)
         self.assertIsInstance(DiskArbitration.kDADiskDescriptionVolumeMountableKey, unicode)
@@ -50,9 +41,18 @@ class TestDADisk (TestCase):
         self.assertIsInstance(DiskArbitration.kDADiskDescriptionBusNameKey, unicode)
         self.assertIsInstance(DiskArbitration.kDADiskDescriptionBusPathKey, unicode)
 
+    @min_os_level('10.14.14')
+    def test_constants10_14_4(self):
+        self.assertIsInstance(DiskArbitration.kDADiskDescriptionMediaEncryptedKey, unicode)
+        self.assertIsInstance(DiskArbitration.kDADiskDescriptionMediaEncryptionDetailKey, unicode)
+        self.assertIsInstance(DiskArbitration.kDADiskDescriptionDeviceTDMLockedKey, unicode)
+
+    @expectedFailureIf(os_release().rsplit('.', 1)[0] == '10.10')
+    @min_os_level('10.10')
     def test_types(self):
         self.assertIsCFType(DiskArbitration.DADiskRef)
 
+    @min_os_level('10.10')
     def test_functions(self):
         self.assertIsInstance(DiskArbitration.DADiskGetTypeID(), (int, long))
 
@@ -68,6 +68,8 @@ class TestDADisk (TestCase):
         self.assertResultIsCFRetained(DiskArbitration.DADiskCopyDescription)
         self.assertResultIsCFRetained(DiskArbitration.DADiskCopyWholeDisk)
 
+        DiskArbitration.DADiskCopyIOMedia
+
 
 
 if __name__ == "__main__":
